@@ -3,16 +3,16 @@
 #' A bootstrap sample is a sample that is the same size as the original data set that is made using replacement.  This results in analysis samples that have multiple replicates of some of the original rows of the data. The assessment set is defined as the rows of the original data that were not included in the bootstrap sample. This is often referred to as the "out-of-bag" (OOB) sample. 
 
 #' @details
-#' The argument \code{apparent} enables the option of an additional "resample" where the analysis and assessment data sets are the same as the original data set. This can be required for some types of analysis of the bootstrap results. 
+#' The argument `apparent` enables the option of an additional "resample" where the analysis and assessment data sets are the same as the original data set. This can be required for some types of analysis of the bootstrap results. 
 #' 
-#' The \code{strata} argument is based on a similar argument in the random forest package were the bootstrap samples are conducted \emph{within the stratification variable}. The can help ensure that the number of data points in the bootstrap sample is equivalent to the proportions in the original data set.
+#' The `strata` argument is based on a similar argument in the random forest package were the bootstrap samples are conducted *within the stratification variable*. The can help ensure that the number of data points in the bootstrap sample is equivalent to the proportions in the original data set.
 #'
 #' @inheritParams vfold_cv
 #' @param times The number of bootstrap samples. 
-#' @param strata A variable that is used to conduct stratified sampling. When not \code{NULL}, each bootstrap sample is created within the stratification variable.
-#' @param apparent A logical. Should an extra resample be added where the analysis and holdout subset are the entire data set. This is required for some estimators used by the \code{summary} function that require the apparent error rate.   
+#' @param strata A variable that is used to conduct stratified sampling. When not `NULL`, each bootstrap sample is created within the stratification variable.
+#' @param apparent A logical. Should an extra resample be added where the analysis and holdout subset are the entire data set. This is required for some estimators used by the `summary` function that require the apparent error rate.   
 #' @export
-#' @return  An tibble with classes \code{bootstraps}, \code{rset}, \code{tbl_df}, \code{tbl}, and \code{data.frame}. The results include a column for the data split objects and a column called \code{id} that has a character string with the resample identifier.
+#' @return  An tibble with classes `bootstraps`, `rset`, `tbl_df`, `tbl`, and `data.frame`. The results include a column for the data split objects and a column called `id` that has a character string with the resample identifier.
 #' @examples
 #' bootstraps(mtcars, times = 2)
 #' bootstraps(mtcars, times = 2, apparent = TRUE)
@@ -105,15 +105,8 @@ boot_splits <-
 }
 
 #' @export
-print.bootstraps<- function(x, ...) {
-  details <- attributes(x)
-  cat("# Bootstrap sampling with ", details$times, " resamples ",
-      sep = "")
-  if (details$strata)
-    cat("+ strata")
-  if (any(details$splits$id == "Apparent"))
-    cat(" (includes apparent error rate sample)")
-  cat("\n")
+print.bootstraps <- function(x, ...) {
+  cat("#", pretty(x), "\n")
   class(x) <- class(x)[!(class(x) %in% c("bootstraps", "rset"))]
   print(x)
 }
